@@ -31,6 +31,7 @@ mod build;
 mod cmd;
 mod eject;
 pub mod errors;
+mod export;
 mod help;
 mod prepare;
 mod serve;
@@ -46,6 +47,7 @@ use std::path::PathBuf;
 pub const PERSEUS_VERSION: &str = env!("CARGO_PKG_VERSION");
 pub use build::build;
 pub use eject::{eject, has_ejected};
+pub use export::export;
 pub use help::help;
 pub use prepare::{check_env, prepare};
 pub use serve::serve;
